# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/pool-incentives/v1beta1/incentives.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0osmosis/pool-incentives/v1beta1/incentives.proto\x12\x1eosmosis.poolincentives.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"=\n\x06Params\x12-\n\x0cminted_denom\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"minted_denom\":\x04\x98\xa0\x1f\x00\"u\n\x15LockableDurationsInfo\x12\\\n\x12lockable_durations\x18\x01 \x03(\x0b\x32\x19.google.protobuf.DurationB%\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x19yaml:\"lockable_durations\"\"\xac\x01\n\tDistrInfo\x12[\n\x0ctotal_weight\x18\x01 \x01(\tBE\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x13yaml:\"total_weight\"\xc8\xde\x1f\x00\x12\x42\n\x07records\x18\x02 \x03(\x0b\x32+.osmosis.poolincentives.v1beta1.DistrRecordB\x04\xc8\xde\x1f\x00\"z\n\x0b\x44istrRecord\x12%\n\x08gauge_id\x18\x01 \x01(\x04\x42\x13\xf2\xde\x1f\x0fyaml:\"gauge_id\"\x12>\n\x06weight\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"\xa0\x01\n\x0bPoolToGauge\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\"\n\x08gauge_id\x18\x02 \x01(\x04\x42\x10\xf2\xde\x1f\x0cyaml:\"gauge\"\x12H\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1b\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x0fyaml:\"duration\"\"X\n\x0cPoolToGauges\x12H\n\rpool_to_gauge\x18\x02 \x03(\x0b\x32+.osmosis.poolincentives.v1beta1.PoolToGaugeB\x04\xc8\xde\x1f\x00\x42=Z;github.com/osmosis-labs/osmosis/v14/x/pool-incentives/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.pool_incentives.v1beta1.incentives_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/osmosis-labs/osmosis/v14/x/pool-incentives/types'
  _PARAMS.fields_by_name['minted_denom']._options = None
  _PARAMS.fields_by_name['minted_denom']._serialized_options = b'\362\336\037\023yaml:\"minted_denom\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _LOCKABLEDURATIONSINFO.fields_by_name['lockable_durations']._options = None
  _LOCKABLEDURATIONSINFO.fields_by_name['lockable_durations']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\031yaml:\"lockable_durations\"'
  _DISTRINFO.fields_by_name['total_weight']._options = None
  _DISTRINFO.fields_by_name['total_weight']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\023yaml:\"total_weight\"\310\336\037\000'
  _DISTRINFO.fields_by_name['records']._options = None
  _DISTRINFO.fields_by_name['records']._serialized_options = b'\310\336\037\000'
  _DISTRRECORD.fields_by_name['gauge_id']._options = None
  _DISTRRECORD.fields_by_name['gauge_id']._serialized_options = b'\362\336\037\017yaml:\"gauge_id\"'
  _DISTRRECORD.fields_by_name['weight']._options = None
  _DISTRRECORD.fields_by_name['weight']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _DISTRRECORD._options = None
  _DISTRRECORD._serialized_options = b'\350\240\037\001'
  _POOLTOGAUGE.fields_by_name['pool_id']._options = None
  _POOLTOGAUGE.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _POOLTOGAUGE.fields_by_name['gauge_id']._options = None
  _POOLTOGAUGE.fields_by_name['gauge_id']._serialized_options = b'\362\336\037\014yaml:\"gauge\"'
  _POOLTOGAUGE.fields_by_name['duration']._options = None
  _POOLTOGAUGE.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\017yaml:\"duration\"'
  _POOLTOGAUGES.fields_by_name['pool_to_gauge']._options = None
  _POOLTOGAUGES.fields_by_name['pool_to_gauge']._serialized_options = b'\310\336\037\000'
  _PARAMS._serialized_start=138
  _PARAMS._serialized_end=199
  _LOCKABLEDURATIONSINFO._serialized_start=201
  _LOCKABLEDURATIONSINFO._serialized_end=318
  _DISTRINFO._serialized_start=321
  _DISTRINFO._serialized_end=493
  _DISTRRECORD._serialized_start=495
  _DISTRRECORD._serialized_end=617
  _POOLTOGAUGE._serialized_start=620
  _POOLTOGAUGE._serialized_end=780
  _POOLTOGAUGES._serialized_start=782
  _POOLTOGAUGES._serialized_end=870
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryProposalRequest(google.protobuf.message.Message):
    """QueryProposalRequest is the request type for the Query/Proposal RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    """proposal_id defines the unique id of the proposal."""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_id", b"proposal_id"]) -> None: ...

global___QueryProposalRequest = QueryProposalRequest

@typing_extensions.final
class QueryProposalResponse(google.protobuf.message.Message):
    """QueryProposalResponse is the response type for the Query/Proposal RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_FIELD_NUMBER: builtins.int
    @property
    def proposal(self) -> cosmos.gov.v1beta1.gov_pb2.Proposal: ...
    def __init__(
        self,
        *,
        proposal: cosmos.gov.v1beta1.gov_pb2.Proposal | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proposal", b"proposal"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal", b"proposal"]) -> None: ...

global___QueryProposalResponse = QueryProposalResponse

@typing_extensions.final
class QueryProposalsRequest(google.protobuf.message.Message):
    """QueryProposalsRequest is the request type for the Query/Proposals RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_STATUS_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_status: cosmos.gov.v1beta1.gov_pb2.ProposalStatus.ValueType
    """proposal_status defines the status of the proposals."""
    voter: builtins.str
    """voter defines the voter address for the proposals."""
    depositor: builtins.str
    """depositor defines the deposit addresses from the proposals."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        proposal_status: cosmos.gov.v1beta1.gov_pb2.ProposalStatus.ValueType = ...,
        voter: builtins.str = ...,
        depositor: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["depositor", b"depositor", "pagination", b"pagination", "proposal_status", b"proposal_status", "voter", b"voter"]) -> None: ...

global___QueryProposalsRequest = QueryProposalsRequest

@typing_extensions.final
class QueryProposalsResponse(google.protobuf.message.Message):
    """QueryProposalsResponse is the response type for the Query/Proposals RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSALS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def proposals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Proposal]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        proposals: collections.abc.Iterable[cosmos.gov.v1beta1.gov_pb2.Proposal] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "proposals", b"proposals"]) -> None: ...

global___QueryProposalsResponse = QueryProposalsResponse

@typing_extensions.final
class QueryVoteRequest(google.protobuf.message.Message):
    """QueryVoteRequest is the request type for the Query/Vote RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    """proposal_id defines the unique id of the proposal."""
    voter: builtins.str
    """voter defines the oter address for the proposals."""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        voter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_id", b"proposal_id", "voter", b"voter"]) -> None: ...

global___QueryVoteRequest = QueryVoteRequest

@typing_extensions.final
class QueryVoteResponse(google.protobuf.message.Message):
    """QueryVoteResponse is the response type for the Query/Vote RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTE_FIELD_NUMBER: builtins.int
    @property
    def vote(self) -> cosmos.gov.v1beta1.gov_pb2.Vote:
        """vote defined the queried vote."""
    def __init__(
        self,
        *,
        vote: cosmos.gov.v1beta1.gov_pb2.Vote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vote", b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vote", b"vote"]) -> None: ...

global___QueryVoteResponse = QueryVoteResponse

@typing_extensions.final
class QueryVotesRequest(google.protobuf.message.Message):
    """QueryVotesRequest is the request type for the Query/Votes RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    """proposal_id defines the unique id of the proposal."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "proposal_id", b"proposal_id"]) -> None: ...

global___QueryVotesRequest = QueryVotesRequest

@typing_extensions.final
class QueryVotesResponse(google.protobuf.message.Message):
    """QueryVotesResponse is the response type for the Query/Votes RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Vote]:
        """votes defined the queried votes."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        votes: collections.abc.Iterable[cosmos.gov.v1beta1.gov_pb2.Vote] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "votes", b"votes"]) -> None: ...

global___QueryVotesResponse = QueryVotesResponse

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is the request type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_TYPE_FIELD_NUMBER: builtins.int
    params_type: builtins.str
    """params_type defines which parameters to query for, can be one of "voting",
    "tallying" or "deposit".
    """
    def __init__(
        self,
        *,
        params_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params_type", b"params_type"]) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is the response type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTING_PARAMS_FIELD_NUMBER: builtins.int
    DEPOSIT_PARAMS_FIELD_NUMBER: builtins.int
    TALLY_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def voting_params(self) -> cosmos.gov.v1beta1.gov_pb2.VotingParams:
        """voting_params defines the parameters related to voting."""
    @property
    def deposit_params(self) -> cosmos.gov.v1beta1.gov_pb2.DepositParams:
        """deposit_params defines the parameters related to deposit."""
    @property
    def tally_params(self) -> cosmos.gov.v1beta1.gov_pb2.TallyParams:
        """tally_params defines the parameters related to tally."""
    def __init__(
        self,
        *,
        voting_params: cosmos.gov.v1beta1.gov_pb2.VotingParams | None = ...,
        deposit_params: cosmos.gov.v1beta1.gov_pb2.DepositParams | None = ...,
        tally_params: cosmos.gov.v1beta1.gov_pb2.TallyParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deposit_params", b"deposit_params", "tally_params", b"tally_params", "voting_params", b"voting_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deposit_params", b"deposit_params", "tally_params", b"tally_params", "voting_params", b"voting_params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QueryDepositRequest(google.protobuf.message.Message):
    """QueryDepositRequest is the request type for the Query/Deposit RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    """proposal_id defines the unique id of the proposal."""
    depositor: builtins.str
    """depositor defines the deposit addresses from the proposals."""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        depositor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["depositor", b"depositor", "proposal_id", b"proposal_id"]) -> None: ...

global___QueryDepositRequest = QueryDepositRequest

@typing_extensions.final
class QueryDepositResponse(google.protobuf.message.Message):
    """QueryDepositResponse is the response type for the Query/Deposit RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPOSIT_FIELD_NUMBER: builtins.int
    @property
    def deposit(self) -> cosmos.gov.v1beta1.gov_pb2.Deposit:
        """deposit defines the requested deposit."""
    def __init__(
        self,
        *,
        deposit: cosmos.gov.v1beta1.gov_pb2.Deposit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deposit", b"deposit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deposit", b"deposit"]) -> None: ...

global___QueryDepositResponse = QueryDepositResponse

@typing_extensions.final
class QueryDepositsRequest(google.protobuf.message.Message):
    """QueryDepositsRequest is the request type for the Query/Deposits RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    """proposal_id defines the unique id of the proposal."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "proposal_id", b"proposal_id"]) -> None: ...

global___QueryDepositsRequest = QueryDepositsRequest

@typing_extensions.final
class QueryDepositsResponse(google.protobuf.message.Message):
    """QueryDepositsResponse is the response type for the Query/Deposits RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPOSITS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def deposits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Deposit]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        deposits: collections.abc.Iterable[cosmos.gov.v1beta1.gov_pb2.Deposit] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deposits", b"deposits", "pagination", b"pagination"]) -> None: ...

global___QueryDepositsResponse = QueryDepositsResponse

@typing_extensions.final
class QueryTallyResultRequest(google.protobuf.message.Message):
    """QueryTallyResultRequest is the request type for the Query/Tally RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    """proposal_id defines the unique id of the proposal."""
    def __init__(
        self,
        *,
        proposal_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_id", b"proposal_id"]) -> None: ...

global___QueryTallyResultRequest = QueryTallyResultRequest

@typing_extensions.final
class QueryTallyResultResponse(google.protobuf.message.Message):
    """QueryTallyResultResponse is the response type for the Query/Tally RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALLY_FIELD_NUMBER: builtins.int
    @property
    def tally(self) -> cosmos.gov.v1beta1.gov_pb2.TallyResult:
        """tally defines the requested tally."""
    def __init__(
        self,
        *,
        tally: cosmos.gov.v1beta1.gov_pb2.TallyResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tally", b"tally"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tally", b"tally"]) -> None: ...

global___QueryTallyResultResponse = QueryTallyResultResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.mint.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query provides defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        cosmos.mint.v1beta1.query_pb2.QueryParamsRequest,
        cosmos.mint.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params returns the total set of minting parameters."""
    Inflation: grpc.UnaryUnaryMultiCallable[
        cosmos.mint.v1beta1.query_pb2.QueryInflationRequest,
        cosmos.mint.v1beta1.query_pb2.QueryInflationResponse,
    ]
    """Inflation returns the current minting inflation value."""
    AnnualProvisions: grpc.UnaryUnaryMultiCallable[
        cosmos.mint.v1beta1.query_pb2.QueryAnnualProvisionsRequest,
        cosmos.mint.v1beta1.query_pb2.QueryAnnualProvisionsResponse,
    ]
    """AnnualProvisions current minting annual provisions value."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query provides defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: cosmos.mint.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.mint.v1beta1.query_pb2.QueryParamsResponse:
        """Params returns the total set of minting parameters."""
    @abc.abstractmethod
    def Inflation(
        self,
        request: cosmos.mint.v1beta1.query_pb2.QueryInflationRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.mint.v1beta1.query_pb2.QueryInflationResponse:
        """Inflation returns the current minting inflation value."""
    @abc.abstractmethod
    def AnnualProvisions(
        self,
        request: cosmos.mint.v1beta1.query_pb2.QueryAnnualProvisionsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.mint.v1beta1.query_pb2.QueryAnnualProvisionsResponse:
        """AnnualProvisions current minting annual provisions value."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/v2/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.gamm.v1beta1 import tx_pb2 as osmosis_dot_gamm_dot_v1beta1_dot_tx__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bosmosis/gamm/v2/query.proto\x12\x0fosmosis.gamm.v2\x1a\x14gogoproto/gogo.proto\x1a\x1dosmosis/gamm/v1beta1/tx.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xac\x01\n\x15QuerySpotPriceRequest\x12#\n\x07pool_id\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x35\n\x10\x62\x61se_asset_denom\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"base_asset_denom\"\x12\x37\n\x11quote_asset_denom\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"quote_asset_denom\"\"C\n\x16QuerySpotPriceResponse\x12)\n\nspot_price\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"spot_price\"2\x97\x01\n\x05Query\x12\x8d\x01\n\tSpotPrice\x12&.osmosis.gamm.v2.QuerySpotPriceRequest\x1a\'.osmosis.gamm.v2.QuerySpotPriceResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/osmosis/gamm/v2/pools/{pool_id}/pricesB4Z2github.com/osmosis-labs/osmosis/v14/x/gamm/v2typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.v2.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/gamm/v2types'
  _QUERYSPOTPRICEREQUEST.fields_by_name['pool_id']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYSPOTPRICEREQUEST.fields_by_name['base_asset_denom']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['base_asset_denom']._serialized_options = b'\362\336\037\027yaml:\"base_asset_denom\"'
  _QUERYSPOTPRICEREQUEST.fields_by_name['quote_asset_denom']._options = None
  _QUERYSPOTPRICEREQUEST.fields_by_name['quote_asset_denom']._serialized_options = b'\362\336\037\030yaml:\"quote_asset_denom\"'
  _QUERYSPOTPRICERESPONSE.fields_by_name['spot_price']._options = None
  _QUERYSPOTPRICERESPONSE.fields_by_name['spot_price']._serialized_options = b'\362\336\037\021yaml:\"spot_price\"'
  _QUERY.methods_by_name['SpotPrice']._options = None
  _QUERY.methods_by_name['SpotPrice']._serialized_options = b'\202\323\344\223\002)\022\'/osmosis/gamm/v2/pools/{pool_id}/prices'
  _QUERYSPOTPRICEREQUEST._serialized_start=262
  _QUERYSPOTPRICEREQUEST._serialized_end=434
  _QUERYSPOTPRICERESPONSE._serialized_start=436
  _QUERYSPOTPRICERESPONSE._serialized_end=503
  _QUERY._serialized_start=506
  _QUERY._serialized_end=657
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgUnjail(google.protobuf.message.Message):
    """MsgUnjail defines the Msg/Unjail request type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDR_FIELD_NUMBER: builtins.int
    validator_addr: builtins.str
    def __init__(
        self,
        *,
        validator_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator_addr", b"validator_addr"]) -> None: ...

global___MsgUnjail = MsgUnjail

@typing_extensions.final
class MsgUnjailResponse(google.protobuf.message.Message):
    """MsgUnjailResponse defines the Msg/Unjail response type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgUnjailResponse = MsgUnjailResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/superfluid/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fosmosis/superfluid/params.proto\x12\x12osmosis.superfluid\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"s\n\x06Params\x12i\n\x13minimum_risk_factor\x18\x01 \x01(\tBL\xf2\xde\x1f\x1ayaml:\"minimum_risk_factor\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x38Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.superfluid.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/types'
  _PARAMS.fields_by_name['minimum_risk_factor']._options = None
  _PARAMS.fields_by_name['minimum_risk_factor']._serialized_options = b'\362\336\037\032yaml:\"minimum_risk_factor\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._serialized_start=109
  _PARAMS._serialized_end=224
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QuerySpotPriceRequest(google.protobuf.message.Message):
    """QuerySpotPriceRequest defines the gRPC request structure for a SpotPrice
    query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_DENOM_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_DENOM_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset_denom: builtins.str
    quote_asset_denom: builtins.str
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset_denom: builtins.str = ...,
        quote_asset_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_denom", b"base_asset_denom", "pool_id", b"pool_id", "quote_asset_denom", b"quote_asset_denom"]) -> None: ...

global___QuerySpotPriceRequest = QuerySpotPriceRequest

@typing_extensions.final
class QuerySpotPriceResponse(google.protobuf.message.Message):
    """QuerySpotPriceResponse defines the gRPC response structure for a SpotPrice
    query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPOT_PRICE_FIELD_NUMBER: builtins.int
    spot_price: builtins.str
    """String of the Dec. Ex) 10.203uatom"""
    def __init__(
        self,
        *,
        spot_price: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["spot_price", b"spot_price"]) -> None: ...

global___QuerySpotPriceResponse = QuerySpotPriceResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.staking.v1beta1.staking_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgCreateValidator(google.protobuf.message.Message):
    """MsgCreateValidator defines a SDK message for creating a new validator."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    COMMISSION_FIELD_NUMBER: builtins.int
    MIN_SELF_DELEGATION_FIELD_NUMBER: builtins.int
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    PUBKEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> cosmos.staking.v1beta1.staking_pb2.Description: ...
    @property
    def commission(self) -> cosmos.staking.v1beta1.staking_pb2.CommissionRates: ...
    min_self_delegation: builtins.str
    delegator_address: builtins.str
    validator_address: builtins.str
    @property
    def pubkey(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def value(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        description: cosmos.staking.v1beta1.staking_pb2.Description | None = ...,
        commission: cosmos.staking.v1beta1.staking_pb2.CommissionRates | None = ...,
        min_self_delegation: builtins.str = ...,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        pubkey: google.protobuf.any_pb2.Any | None = ...,
        value: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["commission", b"commission", "description", b"description", "pubkey", b"pubkey", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commission", b"commission", "delegator_address", b"delegator_address", "description", b"description", "min_self_delegation", b"min_self_delegation", "pubkey", b"pubkey", "validator_address", b"validator_address", "value", b"value"]) -> None: ...

global___MsgCreateValidator = MsgCreateValidator

@typing_extensions.final
class MsgCreateValidatorResponse(google.protobuf.message.Message):
    """MsgCreateValidatorResponse defines the Msg/CreateValidator response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgCreateValidatorResponse = MsgCreateValidatorResponse

@typing_extensions.final
class MsgEditValidator(google.protobuf.message.Message):
    """MsgEditValidator defines a SDK message for editing an existing validator."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    COMMISSION_RATE_FIELD_NUMBER: builtins.int
    MIN_SELF_DELEGATION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> cosmos.staking.v1beta1.staking_pb2.Description: ...
    validator_address: builtins.str
    commission_rate: builtins.str
    """We pass a reference to the new commission rate and min self delegation as
    it's not mandatory to update. If not updated, the deserialized rate will be
    zero with no way to distinguish if an update was intended.
    REF: #2373
    """
    min_self_delegation: builtins.str
    def __init__(
        self,
        *,
        description: cosmos.staking.v1beta1.staking_pb2.Description | None = ...,
        validator_address: builtins.str = ...,
        commission_rate: builtins.str = ...,
        min_self_delegation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["description", b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commission_rate", b"commission_rate", "description", b"description", "min_self_delegation", b"min_self_delegation", "validator_address", b"validator_address"]) -> None: ...

global___MsgEditValidator = MsgEditValidator

@typing_extensions.final
class MsgEditValidatorResponse(google.protobuf.message.Message):
    """MsgEditValidatorResponse defines the Msg/EditValidator response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgEditValidatorResponse = MsgEditValidatorResponse

@typing_extensions.final
class MsgDelegate(google.protobuf.message.Message):
    """MsgDelegate defines a SDK message for performing a delegation of coins
    from a delegator to a validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_address: builtins.str
    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "delegator_address", b"delegator_address", "validator_address", b"validator_address"]) -> None: ...

global___MsgDelegate = MsgDelegate

@typing_extensions.final
class MsgDelegateResponse(google.protobuf.message.Message):
    """MsgDelegateResponse defines the Msg/Delegate response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgDelegateResponse = MsgDelegateResponse

@typing_extensions.final
class MsgBeginRedelegate(google.protobuf.message.Message):
    """MsgBeginRedelegate defines a SDK message for performing a redelegation
    of coins from a delegator and source validator to a destination validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_src_address: builtins.str
    validator_dst_address: builtins.str
    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_src_address: builtins.str = ...,
        validator_dst_address: builtins.str = ...,
        amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "delegator_address", b"delegator_address", "validator_dst_address", b"validator_dst_address", "validator_src_address", b"validator_src_address"]) -> None: ...

global___MsgBeginRedelegate = MsgBeginRedelegate

@typing_extensions.final
class MsgBeginRedelegateResponse(google.protobuf.message.Message):
    """MsgBeginRedelegateResponse defines the Msg/BeginRedelegate response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPLETION_TIME_FIELD_NUMBER: builtins.int
    @property
    def completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        completion_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time"]) -> None: ...

global___MsgBeginRedelegateResponse = MsgBeginRedelegateResponse

@typing_extensions.final
class MsgUndelegate(google.protobuf.message.Message):
    """MsgUndelegate defines a SDK message for performing an undelegation from a
    delegate and a validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_address: builtins.str
    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["amount", b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "delegator_address", b"delegator_address", "validator_address", b"validator_address"]) -> None: ...

global___MsgUndelegate = MsgUndelegate

@typing_extensions.final
class MsgUndelegateResponse(google.protobuf.message.Message):
    """MsgUndelegateResponse defines the Msg/Undelegate response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPLETION_TIME_FIELD_NUMBER: builtins.int
    @property
    def completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        completion_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time"]) -> None: ...

global___MsgUndelegateResponse = MsgUndelegateResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import tendermint.types.evidence_pb2
import tendermint.types.types_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Block(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    LAST_COMMIT_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> tendermint.types.types_pb2.Header: ...
    @property
    def data(self) -> tendermint.types.types_pb2.Data: ...
    @property
    def evidence(self) -> tendermint.types.evidence_pb2.EvidenceList: ...
    @property
    def last_commit(self) -> tendermint.types.types_pb2.Commit: ...
    def __init__(
        self,
        *,
        header: tendermint.types.types_pb2.Header | None = ...,
        data: tendermint.types.types_pb2.Data | None = ...,
        evidence: tendermint.types.evidence_pb2.EvidenceList | None = ...,
        last_commit: tendermint.types.types_pb2.Commit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data", "evidence", b"evidence", "header", b"header", "last_commit", b"last_commit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "evidence", b"evidence", "header", b"header", "last_commit", b"last_commit"]) -> None: ...

global___Block = Block



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SuperfluidAssetType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SuperfluidAssetTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SuperfluidAssetType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SuperfluidAssetTypeNative: _SuperfluidAssetType.ValueType  # 0
    SuperfluidAssetTypeLPShare: _SuperfluidAssetType.ValueType  # 1
    """SuperfluidAssetTypeLendingShare = 2; // for now not exist"""

class SuperfluidAssetType(_SuperfluidAssetType, metaclass=_SuperfluidAssetTypeEnumTypeWrapper):
    """SuperfluidAssetType indicates whether the superfluid asset is
    a native token itself or the lp share of a pool.
    """

SuperfluidAssetTypeNative: SuperfluidAssetType.ValueType  # 0
SuperfluidAssetTypeLPShare: SuperfluidAssetType.ValueType  # 1
"""SuperfluidAssetTypeLendingShare = 2; // for now not exist"""
global___SuperfluidAssetType = SuperfluidAssetType

@typing_extensions.final
class SuperfluidAsset(google.protobuf.message.Message):
    """SuperfluidAsset stores the pair of superfluid asset type and denom pair"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    ASSET_TYPE_FIELD_NUMBER: builtins.int
    denom: builtins.str
    asset_type: global___SuperfluidAssetType.ValueType
    """AssetType indicates whether the superfluid asset is a native token or an lp
    share
    """
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        asset_type: global___SuperfluidAssetType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_type", b"asset_type", "denom", b"denom"]) -> None: ...

global___SuperfluidAsset = SuperfluidAsset

@typing_extensions.final
class SuperfluidIntermediaryAccount(google.protobuf.message.Message):
    """SuperfluidIntermediaryAccount takes the role of intermediary between LP token
    and OSMO tokens for superfluid staking. The intermediary account is the
    actual account responsible for delegation, not the validator account itself.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    VAL_ADDR_FIELD_NUMBER: builtins.int
    GAUGE_ID_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """Denom indicates the denom of the superfluid asset."""
    val_addr: builtins.str
    gauge_id: builtins.int
    """perpetual gauge for rewards distribution"""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        val_addr: builtins.str = ...,
        gauge_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "gauge_id", b"gauge_id", "val_addr", b"val_addr"]) -> None: ...

global___SuperfluidIntermediaryAccount = SuperfluidIntermediaryAccount

@typing_extensions.final
class OsmoEquivalentMultiplierRecord(google.protobuf.message.Message):
    """The Osmo-Equivalent-Multiplier Record for epoch N refers to the osmo worth we
    treat an LP share as having, for all of epoch N. Eventually this is intended
    to be set as the Time-weighted-average-osmo-backing for the entire duration
    of epoch N-1. (Thereby locking whats in use for epoch N as based on the prior
    epochs rewards) However for now, this is not the TWAP but instead the spot
    price at the boundary. For different types of assets in the future, it could
    change.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPOCH_NUMBER_FIELD_NUMBER: builtins.int
    DENOM_FIELD_NUMBER: builtins.int
    MULTIPLIER_FIELD_NUMBER: builtins.int
    epoch_number: builtins.int
    denom: builtins.str
    """superfluid asset denom, can be LP token or native token"""
    multiplier: builtins.str
    def __init__(
        self,
        *,
        epoch_number: builtins.int = ...,
        denom: builtins.str = ...,
        multiplier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "epoch_number", b"epoch_number", "multiplier", b"multiplier"]) -> None: ...

global___OsmoEquivalentMultiplierRecord = OsmoEquivalentMultiplierRecord

@typing_extensions.final
class SuperfluidDelegationRecord(google.protobuf.message.Message):
    """SuperfluidDelegationRecord is a struct used to indicate superfluid
    delegations of an account in the state machine in a user friendly form.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    DELEGATION_AMOUNT_FIELD_NUMBER: builtins.int
    EQUIVALENT_STAKED_AMOUNT_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_address: builtins.str
    @property
    def delegation_amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def equivalent_staked_amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        delegation_amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
        equivalent_staked_amount: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delegation_amount", b"delegation_amount", "equivalent_staked_amount", b"equivalent_staked_amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegation_amount", b"delegation_amount", "delegator_address", b"delegator_address", "equivalent_staked_amount", b"equivalent_staked_amount", "validator_address", b"validator_address"]) -> None: ...

global___SuperfluidDelegationRecord = SuperfluidDelegationRecord

@typing_extensions.final
class LockIdIntermediaryAccountConnection(google.protobuf.message.Message):
    """LockIdIntermediaryAccountConnection is a struct used to indicate the
    relationship between the underlying lock id and superfluid delegation done
    via lp shares.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_ID_FIELD_NUMBER: builtins.int
    INTERMEDIARY_ACCOUNT_FIELD_NUMBER: builtins.int
    lock_id: builtins.int
    intermediary_account: builtins.str
    def __init__(
        self,
        *,
        lock_id: builtins.int = ...,
        intermediary_account: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intermediary_account", b"intermediary_account", "lock_id", b"lock_id"]) -> None: ...

global___LockIdIntermediaryAccountConnection = LockIdIntermediaryAccountConnection

@typing_extensions.final
class UnpoolWhitelistedPools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDS_FIELD_NUMBER: builtins.int
    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        ids: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ids", b"ids"]) -> None: ...

global___UnpoolWhitelistedPools = UnpoolWhitelistedPools



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/mint/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from osmosis.mint.v1beta1 import mint_pb2 as osmosis_dot_mint_dot_v1beta1_dot_mint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n osmosis/mint/v1beta1/query.proto\x12\x14osmosis.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fosmosis/mint/v1beta1/mint.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1c.osmosis.mint.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\x1d\n\x1bQueryEpochProvisionsRequest\"h\n\x1cQueryEpochProvisionsResponse\x12H\n\x10\x65poch_provisions\x18\x01 \x01(\x0c\x42.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x32\xb8\x02\n\x05Query\x12\x83\x01\n\x06Params\x12(.osmosis.mint.v1beta1.QueryParamsRequest\x1a).osmosis.mint.v1beta1.QueryParamsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/osmosis/mint/v1beta1/params\x12\xa8\x01\n\x0f\x45pochProvisions\x12\x31.osmosis.mint.v1beta1.QueryEpochProvisionsRequest\x1a\x32.osmosis.mint.v1beta1.QueryEpochProvisionsResponse\".\x82\xd3\xe4\x93\x02(\x12&/osmosis/mint/v1beta1/epoch_provisionsB2Z0github.com/osmosis-labs/osmosis/v14/x/mint/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.mint.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/mint/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYEPOCHPROVISIONSRESPONSE.fields_by_name['epoch_provisions']._options = None
  _QUERYEPOCHPROVISIONSRESPONSE.fields_by_name['epoch_provisions']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\036\022\034/osmosis/mint/v1beta1/params'
  _QUERY.methods_by_name['EpochProvisions']._options = None
  _QUERY.methods_by_name['EpochProvisions']._serialized_options = b'\202\323\344\223\002(\022&/osmosis/mint/v1beta1/epoch_provisions'
  _QUERYPARAMSREQUEST._serialized_start=143
  _QUERYPARAMSREQUEST._serialized_end=163
  _QUERYPARAMSRESPONSE._serialized_start=165
  _QUERYPARAMSRESPONSE._serialized_end=238
  _QUERYEPOCHPROVISIONSREQUEST._serialized_start=240
  _QUERYEPOCHPROVISIONSREQUEST._serialized_end=269
  _QUERYEPOCHPROVISIONSRESPONSE._serialized_start=271
  _QUERYEPOCHPROVISIONSRESPONSE._serialized_end=375
  _QUERY._serialized_start=378
  _QUERY._serialized_end=690
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/tokenfactory/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from osmosis.tokenfactory.v1beta1 import authorityMetadata_pb2 as osmosis_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2
from osmosis.tokenfactory.v1beta1 import params_pb2 as osmosis_dot_tokenfactory_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(osmosis/tokenfactory/v1beta1/query.proto\x12\x1cosmosis.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x34osmosis/tokenfactory/v1beta1/authorityMetadata.proto\x1a)osmosis/tokenfactory/v1beta1/params.proto\"\x14\n\x12QueryParamsRequest\"Q\n\x13QueryParamsResponse\x12:\n\x06params\x18\x01 \x01(\x0b\x32$.osmosis.tokenfactory.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"E\n\"QueryDenomAuthorityMetadataRequest\x12\x1f\n\x05\x64\x65nom\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\"\x9a\x01\n#QueryDenomAuthorityMetadataResponse\x12s\n\x12\x61uthority_metadata\x18\x01 \x01(\x0b\x32\x34.osmosis.tokenfactory.v1beta1.DenomAuthorityMetadataB!\xf2\xde\x1f\x19yaml:\"authority_metadata\"\xc8\xde\x1f\x00\"D\n\x1dQueryDenomsFromCreatorRequest\x12#\n\x07\x63reator\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"creator\"\"C\n\x1eQueryDenomsFromCreatorResponse\x12!\n\x06\x64\x65noms\x18\x01 \x03(\tB\x11\xf2\xde\x1f\ryaml:\"denoms\"2\xe4\x04\n\x05Query\x12\x9b\x01\n\x06Params\x12\x30.osmosis.tokenfactory.v1beta1.QueryParamsRequest\x1a\x31.osmosis.tokenfactory.v1beta1.QueryParamsResponse\",\x82\xd3\xe4\x93\x02&\x12$/osmosis/tokenfactory/v1beta1/params\x12\xe6\x01\n\x16\x44\x65nomAuthorityMetadata\x12@.osmosis.tokenfactory.v1beta1.QueryDenomAuthorityMetadataRequest\x1a\x41.osmosis.tokenfactory.v1beta1.QueryDenomAuthorityMetadataResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/osmosis/tokenfactory/v1beta1/denoms/{denom}/authority_metadata\x12\xd3\x01\n\x11\x44\x65nomsFromCreator\x12;.osmosis.tokenfactory.v1beta1.QueryDenomsFromCreatorRequest\x1a<.osmosis.tokenfactory.v1beta1.QueryDenomsFromCreatorResponse\"C\x82\xd3\xe4\x93\x02=\x12;/osmosis/tokenfactory/v1beta1/denoms_from_creator/{creator}B:Z8github.com/osmosis-labs/osmosis/v14/x/tokenfactory/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.tokenfactory.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/osmosis-labs/osmosis/v14/x/tokenfactory/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYDENOMAUTHORITYMETADATAREQUEST.fields_by_name['denom']._options = None
  _QUERYDENOMAUTHORITYMETADATAREQUEST.fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _QUERYDENOMAUTHORITYMETADATARESPONSE.fields_by_name['authority_metadata']._options = None
  _QUERYDENOMAUTHORITYMETADATARESPONSE.fields_by_name['authority_metadata']._serialized_options = b'\362\336\037\031yaml:\"authority_metadata\"\310\336\037\000'
  _QUERYDENOMSFROMCREATORREQUEST.fields_by_name['creator']._options = None
  _QUERYDENOMSFROMCREATORREQUEST.fields_by_name['creator']._serialized_options = b'\362\336\037\016yaml:\"creator\"'
  _QUERYDENOMSFROMCREATORRESPONSE.fields_by_name['denoms']._options = None
  _QUERYDENOMSFROMCREATORRESPONSE.fields_by_name['denoms']._serialized_options = b'\362\336\037\ryaml:\"denoms\"'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002&\022$/osmosis/tokenfactory/v1beta1/params'
  _QUERY.methods_by_name['DenomAuthorityMetadata']._options = None
  _QUERY.methods_by_name['DenomAuthorityMetadata']._serialized_options = b'\202\323\344\223\002A\022?/osmosis/tokenfactory/v1beta1/denoms/{denom}/authority_metadata'
  _QUERY.methods_by_name['DenomsFromCreator']._options = None
  _QUERY.methods_by_name['DenomsFromCreator']._serialized_options = b'\202\323\344\223\002=\022;/osmosis/tokenfactory/v1beta1/denoms_from_creator/{creator}'
  _QUERYPARAMSREQUEST._serialized_start=267
  _QUERYPARAMSREQUEST._serialized_end=287
  _QUERYPARAMSRESPONSE._serialized_start=289
  _QUERYPARAMSRESPONSE._serialized_end=370
  _QUERYDENOMAUTHORITYMETADATAREQUEST._serialized_start=372
  _QUERYDENOMAUTHORITYMETADATAREQUEST._serialized_end=441
  _QUERYDENOMAUTHORITYMETADATARESPONSE._serialized_start=444
  _QUERYDENOMAUTHORITYMETADATARESPONSE._serialized_end=598
  _QUERYDENOMSFROMCREATORREQUEST._serialized_start=600
  _QUERYDENOMSFROMCREATORREQUEST._serialized_end=668
  _QUERYDENOMSFROMCREATORRESPONSE._serialized_start=670
  _QUERYDENOMSFROMCREATORRESPONSE._serialized_end=737
  _QUERY._serialized_start=740
  _QUERY._serialized_end=1352
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/mint/v1beta1/mint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fosmosis/mint/v1beta1/mint.proto\x12\x14osmosis.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\"m\n\x06Minter\x12\x63\n\x10\x65poch_provisions\x18\x01 \x01(\tBI\xf2\xde\x1f\x17yaml:\"epoch_provisions\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x87\x01\n\x0fWeightedAddress\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12O\n\x06weight\x18\x02 \x01(\tB?\xf2\xde\x1f\ryaml:\"weight\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x97\x03\n\x17\x44istributionProportions\x12Q\n\x07staking\x18\x01 \x01(\tB@\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0eyaml:\"staking\"\xc8\xde\x1f\x00\x12\x61\n\x0fpool_incentives\x18\x02 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x16yaml:\"pool_incentives\"\xc8\xde\x1f\x00\x12\x65\n\x11\x64\x65veloper_rewards\x18\x03 \x01(\tBJ\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x18yaml:\"developer_rewards\"\xc8\xde\x1f\x00\x12_\n\x0e\x63ommunity_pool\x18\x04 \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x15yaml:\"community_pool\"\xc8\xde\x1f\x00\"\xbc\x05\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12s\n\x18genesis_epoch_provisions\x18\x02 \x01(\tBQ\xf2\xde\x1f\x1fyaml:\"genesis_epoch_provisions\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x35\n\x10\x65poch_identifier\x18\x03 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"epoch_identifier\"\x12I\n\x1areduction_period_in_epochs\x18\x04 \x01(\x03\x42%\xf2\xde\x1f!yaml:\"reduction_period_in_epochs\"\x12\x63\n\x10reduction_factor\x18\x05 \x01(\tBI\xf2\xde\x1f\x17yaml:\"reduction_factor\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12U\n\x18\x64istribution_proportions\x18\x06 \x01(\x0b\x32-.osmosis.mint.v1beta1.DistributionProportionsB\x04\xc8\xde\x1f\x00\x12~\n$weighted_developer_rewards_receivers\x18\x07 \x03(\x0b\x32%.osmosis.mint.v1beta1.WeightedAddressB)\xf2\xde\x1f!yaml:\"developer_rewards_receiver\"\xc8\xde\x1f\x00\x12\x65\n(minting_rewards_distribution_start_epoch\x18\x08 \x01(\x03\x42\x33\xf2\xde\x1f/yaml:\"minting_rewards_distribution_start_epoch\":\x04\x98\xa0\x1f\x00\x42\x32Z0github.com/osmosis-labs/osmosis/v14/x/mint/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.mint.v1beta1.mint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/osmosis-labs/osmosis/v14/x/mint/types'
  _MINTER.fields_by_name['epoch_provisions']._options = None
  _MINTER.fields_by_name['epoch_provisions']._serialized_options = b'\362\336\037\027yaml:\"epoch_provisions\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _WEIGHTEDADDRESS.fields_by_name['address']._options = None
  _WEIGHTEDADDRESS.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _WEIGHTEDADDRESS.fields_by_name['weight']._options = None
  _WEIGHTEDADDRESS.fields_by_name['weight']._serialized_options = b'\362\336\037\ryaml:\"weight\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['staking']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['staking']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\016yaml:\"staking\"\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['pool_incentives']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['pool_incentives']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\026yaml:\"pool_incentives\"\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['developer_rewards']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['developer_rewards']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\030yaml:\"developer_rewards\"\310\336\037\000'
  _DISTRIBUTIONPROPORTIONS.fields_by_name['community_pool']._options = None
  _DISTRIBUTIONPROPORTIONS.fields_by_name['community_pool']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\025yaml:\"community_pool\"\310\336\037\000'
  _PARAMS.fields_by_name['genesis_epoch_provisions']._options = None
  _PARAMS.fields_by_name['genesis_epoch_provisions']._serialized_options = b'\362\336\037\037yaml:\"genesis_epoch_provisions\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['epoch_identifier']._options = None
  _PARAMS.fields_by_name['epoch_identifier']._serialized_options = b'\362\336\037\027yaml:\"epoch_identifier\"'
  _PARAMS.fields_by_name['reduction_period_in_epochs']._options = None
  _PARAMS.fields_by_name['reduction_period_in_epochs']._serialized_options = b'\362\336\037!yaml:\"reduction_period_in_epochs\"'
  _PARAMS.fields_by_name['reduction_factor']._options = None
  _PARAMS.fields_by_name['reduction_factor']._serialized_options = b'\362\336\037\027yaml:\"reduction_factor\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['distribution_proportions']._options = None
  _PARAMS.fields_by_name['distribution_proportions']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['weighted_developer_rewards_receivers']._options = None
  _PARAMS.fields_by_name['weighted_developer_rewards_receivers']._serialized_options = b'\362\336\037!yaml:\"developer_rewards_receiver\"\310\336\037\000'
  _PARAMS.fields_by_name['minting_rewards_distribution_start_epoch']._options = None
  _PARAMS.fields_by_name['minting_rewards_distribution_start_epoch']._serialized_options = b'\362\336\037/yaml:\"minting_rewards_distribution_start_epoch\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _MINTER._serialized_start=171
  _MINTER._serialized_end=280
  _WEIGHTEDADDRESS._serialized_start=283
  _WEIGHTEDADDRESS._serialized_end=418
  _DISTRIBUTIONPROPORTIONS._serialized_start=421
  _DISTRIBUTIONPROPORTIONS._serialized_end=828
  _PARAMS._serialized_start=831
  _PARAMS._serialized_end=1531
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.staking.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Validators: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryValidatorsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryValidatorsResponse,
    ]
    """Validators queries all validators that match the given status."""
    Validator: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryValidatorRequest,
        cosmos.staking.v1beta1.query_pb2.QueryValidatorResponse,
    ]
    """Validator queries validator info for given validator address."""
    ValidatorDelegations: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryValidatorDelegationsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryValidatorDelegationsResponse,
    ]
    """ValidatorDelegations queries delegate info for given validator."""
    ValidatorUnbondingDelegations: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryValidatorUnbondingDelegationsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryValidatorUnbondingDelegationsResponse,
    ]
    """ValidatorUnbondingDelegations queries unbonding delegations of a validator."""
    Delegation: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryDelegationRequest,
        cosmos.staking.v1beta1.query_pb2.QueryDelegationResponse,
    ]
    """Delegation queries delegate info for given validator delegator pair."""
    UnbondingDelegation: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryUnbondingDelegationRequest,
        cosmos.staking.v1beta1.query_pb2.QueryUnbondingDelegationResponse,
    ]
    """UnbondingDelegation queries unbonding info for given validator delegator
    pair.
    """
    DelegatorDelegations: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorDelegationsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorDelegationsResponse,
    ]
    """DelegatorDelegations queries all delegations of a given delegator address."""
    DelegatorUnbondingDelegations: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorUnbondingDelegationsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorUnbondingDelegationsResponse,
    ]
    """DelegatorUnbondingDelegations queries all unbonding delegations of a given
    delegator address.
    """
    Redelegations: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryRedelegationsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryRedelegationsResponse,
    ]
    """Redelegations queries redelegations of given address."""
    DelegatorValidators: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorsResponse,
    ]
    """DelegatorValidators queries all validators info for given delegator
    address.
    """
    DelegatorValidator: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorRequest,
        cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorResponse,
    ]
    """DelegatorValidator queries validator info for given delegator validator
    pair.
    """
    HistoricalInfo: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryHistoricalInfoRequest,
        cosmos.staking.v1beta1.query_pb2.QueryHistoricalInfoResponse,
    ]
    """HistoricalInfo queries the historical info for given height."""
    Pool: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryPoolRequest,
        cosmos.staking.v1beta1.query_pb2.QueryPoolResponse,
    ]
    """Pool queries the pool info."""
    Params: grpc.UnaryUnaryMultiCallable[
        cosmos.staking.v1beta1.query_pb2.QueryParamsRequest,
        cosmos.staking.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Parameters queries the staking parameters."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Validators(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryValidatorsResponse:
        """Validators queries all validators that match the given status."""
    @abc.abstractmethod
    def Validator(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryValidatorRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryValidatorResponse:
        """Validator queries validator info for given validator address."""
    @abc.abstractmethod
    def ValidatorDelegations(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryValidatorDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryValidatorDelegationsResponse:
        """ValidatorDelegations queries delegate info for given validator."""
    @abc.abstractmethod
    def ValidatorUnbondingDelegations(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryValidatorUnbondingDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryValidatorUnbondingDelegationsResponse:
        """ValidatorUnbondingDelegations queries unbonding delegations of a validator."""
    @abc.abstractmethod
    def Delegation(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryDelegationRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryDelegationResponse:
        """Delegation queries delegate info for given validator delegator pair."""
    @abc.abstractmethod
    def UnbondingDelegation(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryUnbondingDelegationRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryUnbondingDelegationResponse:
        """UnbondingDelegation queries unbonding info for given validator delegator
        pair.
        """
    @abc.abstractmethod
    def DelegatorDelegations(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryDelegatorDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryDelegatorDelegationsResponse:
        """DelegatorDelegations queries all delegations of a given delegator address."""
    @abc.abstractmethod
    def DelegatorUnbondingDelegations(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryDelegatorUnbondingDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryDelegatorUnbondingDelegationsResponse:
        """DelegatorUnbondingDelegations queries all unbonding delegations of a given
        delegator address.
        """
    @abc.abstractmethod
    def Redelegations(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryRedelegationsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryRedelegationsResponse:
        """Redelegations queries redelegations of given address."""
    @abc.abstractmethod
    def DelegatorValidators(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorsResponse:
        """DelegatorValidators queries all validators info for given delegator
        address.
        """
    @abc.abstractmethod
    def DelegatorValidator(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryDelegatorValidatorResponse:
        """DelegatorValidator queries validator info for given delegator validator
        pair.
        """
    @abc.abstractmethod
    def HistoricalInfo(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryHistoricalInfoRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryHistoricalInfoResponse:
        """HistoricalInfo queries the historical info for given height."""
    @abc.abstractmethod
    def Pool(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryPoolRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryPoolResponse:
        """Pool queries the pool info."""
    @abc.abstractmethod
    def Params(
        self,
        request: cosmos.staking.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.staking.v1beta1.query_pb2.QueryParamsResponse:
        """Parameters queries the staking parameters."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgVerifyInvariant(google.protobuf.message.Message):
    """MsgVerifyInvariant represents a message to verify a particular invariance."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    INVARIANT_MODULE_NAME_FIELD_NUMBER: builtins.int
    INVARIANT_ROUTE_FIELD_NUMBER: builtins.int
    sender: builtins.str
    invariant_module_name: builtins.str
    invariant_route: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        invariant_module_name: builtins.str = ...,
        invariant_route: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invariant_module_name", b"invariant_module_name", "invariant_route", b"invariant_route", "sender", b"sender"]) -> None: ...

global___MsgVerifyInvariant = MsgVerifyInvariant

@typing_extensions.final
class MsgVerifyInvariantResponse(google.protobuf.message.Message):
    """MsgVerifyInvariantResponse defines the Msg/VerifyInvariant response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgVerifyInvariantResponse = MsgVerifyInvariantResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import osmosis.lockup.lock_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Gauge(google.protobuf.message.Message):
    """Gauge is an object that stores and distributes yields to recipients who
    satisfy certain conditions. Currently gauges support conditions around the
    duration for which a given denom is locked.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IS_PERPETUAL_FIELD_NUMBER: builtins.int
    DISTRIBUTE_TO_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    NUM_EPOCHS_PAID_OVER_FIELD_NUMBER: builtins.int
    FILLED_EPOCHS_FIELD_NUMBER: builtins.int
    DISTRIBUTED_COINS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """id is the unique ID of a Gauge"""
    is_perpetual: builtins.bool
    """is_perpetual is a flag to show if it's a perpetual or non-perpetual gauge
    Non-perpetual gauges distribute their tokens equally per epoch while the
    gauge is in the active period. Perpetual gauges distribute all their tokens
    at a single time and only distribute their tokens again once the gauge is
    refilled, Intended for use with incentives that get refilled daily.
    """
    @property
    def distribute_to(self) -> osmosis.lockup.lock_pb2.QueryCondition:
        """distribute_to is where the gauge rewards are distributed to.
        This is queried via lock duration or by timestamp
        """
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """coins is the total amount of coins that have been in the gauge
        Can distribute multiple coin denoms
        """
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """start_time is the distribution start time"""
    num_epochs_paid_over: builtins.int
    """num_epochs_paid_over is the number of total epochs distribution will be
    completed over
    """
    filled_epochs: builtins.int
    """filled_epochs is the number of epochs distribution has been completed on
    already
    """
    @property
    def distributed_coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """distributed_coins are coins that have been distributed already"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        is_perpetual: builtins.bool = ...,
        distribute_to: osmosis.lockup.lock_pb2.QueryCondition | None = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        num_epochs_paid_over: builtins.int = ...,
        filled_epochs: builtins.int = ...,
        distributed_coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distribute_to", b"distribute_to", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins", "distribute_to", b"distribute_to", "distributed_coins", b"distributed_coins", "filled_epochs", b"filled_epochs", "id", b"id", "is_perpetual", b"is_perpetual", "num_epochs_paid_over", b"num_epochs_paid_over", "start_time", b"start_time"]) -> None: ...

global___Gauge = Gauge

@typing_extensions.final
class LockableDurationsInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]:
        """List of incentivised durations that gauges will pay out to"""
    def __init__(
        self,
        *,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lockable_durations", b"lockable_durations"]) -> None: ...

global___LockableDurationsInfo = LockableDurationsInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.pool_incentives.v1beta1.incentives_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ReplacePoolIncentivesProposal(google.protobuf.message.Message):
    """ReplacePoolIncentivesProposal is a gov Content type for updating the pool
    incentives. If a ReplacePoolIncentivesProposal passes, the proposal’s records
    override the existing DistrRecords set in the module. Each record has a
    specified gauge id and weight, and the incentives are distributed to each
    gauge according to weight/total_weight. The incentives are put in the fee
    pool and it is allocated to gauges and community pool by the DistrRecords
    configuration. Note that gaugeId=0 represents the community pool.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECORDS_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.pool_incentives.v1beta1.incentives_pb2.DistrRecord]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        records: collections.abc.Iterable[osmosis.pool_incentives.v1beta1.incentives_pb2.DistrRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "records", b"records", "title", b"title"]) -> None: ...

global___ReplacePoolIncentivesProposal = ReplacePoolIncentivesProposal

@typing_extensions.final
class UpdatePoolIncentivesProposal(google.protobuf.message.Message):
    """UpdatePoolIncentivesProposal is a gov Content type for updating the pool
    incentives. If a UpdatePoolIncentivesProposal passes, all the DistrRecords
    in the proposals are edited. An existing DistrRecord is not overriden unless
    explicitly included in the proposal.
    This differs from an ReplacePoolIncentivesProposal because it only does an
    in place update of the DistrRecords for gauges explicitly mentioned in the
    proposal.

    For example: if the existing DistrRecords were:
    [(Gauge 0, 5), (Gauge 1, 6), (Gauge 2, 6)]
    An UpdatePoolIncentivesProposal includes
    [(Gauge 1, 0), (Gauge 2, 4), (Gauge 3, 10)]
    This would delete Gauge 1, Edit Gauge 2, and Add Gauge 3
    The result DistrRecords in state would be:
    [(Gauge 0, 5), (Gauge 2, 4), (Gauge 3, 10)]
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECORDS_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.pool_incentives.v1beta1.incentives_pb2.DistrRecord]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        records: collections.abc.Iterable[osmosis.pool_incentives.v1beta1.incentives_pb2.DistrRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "records", b"records", "title", b"title"]) -> None: ...

global___UpdatePoolIncentivesProposal = UpdatePoolIncentivesProposal



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.feegrant.v1beta1.feegrant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryAllowanceRequest(google.protobuf.message.Message):
    """QueryAllowanceRequest is the request type for the Query/Allowance RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    granter: builtins.str
    """granter is the address of the user granting an allowance of their funds."""
    grantee: builtins.str
    """grantee is the address of the user being granted an allowance of another user's funds."""
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___QueryAllowanceRequest = QueryAllowanceRequest

@typing_extensions.final
class QueryAllowanceResponse(google.protobuf.message.Message):
    """QueryAllowanceResponse is the response type for the Query/Allowance RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCE_FIELD_NUMBER: builtins.int
    @property
    def allowance(self) -> cosmos.feegrant.v1beta1.feegrant_pb2.Grant:
        """allowance is a allowance granted for grantee by granter."""
    def __init__(
        self,
        *,
        allowance: cosmos.feegrant.v1beta1.feegrant_pb2.Grant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> None: ...

global___QueryAllowanceResponse = QueryAllowanceResponse

@typing_extensions.final
class QueryAllowancesRequest(google.protobuf.message.Message):
    """QueryAllowancesRequest is the request type for the Query/Allowances RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTEE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    grantee: builtins.str
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
    def __init__(
        self,
        *,
        grantee: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "pagination", b"pagination"]) -> None: ...

global___QueryAllowancesRequest = QueryAllowancesRequest

@typing_extensions.final
class QueryAllowancesResponse(google.protobuf.message.Message):
    """QueryAllowancesResponse is the response type for the Query/Allowances RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def allowances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]:
        """allowances are allowance's granted for grantee by granter."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
    def __init__(
        self,
        *,
        allowances: collections.abc.Iterable[cosmos.feegrant.v1beta1.feegrant_pb2.Grant] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowances", b"allowances", "pagination", b"pagination"]) -> None: ...

global___QueryAllowancesResponse = QueryAllowancesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/superfluid/superfluid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#osmosis/superfluid/superfluid.proto\x12\x12osmosis.superfluid\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"g\n\x0fSuperfluidAsset\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12;\n\nasset_type\x18\x02 \x01(\x0e\x32\'.osmosis.superfluid.SuperfluidAssetType:\x08\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\"R\n\x1dSuperfluidIntermediaryAccount\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08val_addr\x18\x02 \x01(\t\x12\x10\n\x08gauge_id\x18\x03 \x01(\x04\"\x9e\x01\n\x1eOsmoEquivalentMultiplierRecord\x12\x14\n\x0c\x65poch_number\x18\x01 \x01(\x03\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12W\n\nmultiplier\x18\x03 \x01(\tBC\xf2\xde\x1f\x11yaml:\"multiplier\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa3\x02\n\x1aSuperfluidDelegationRecord\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t\x12\x65\n\x11\x64\x65legation_amount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\x12h\n\x18\x65quivalent_staked_amount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB+\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\"T\n#LockIdIntermediaryAccountConnection\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\x1c\n\x14intermediary_account\x18\x02 \x01(\t\"%\n\x16UnpoolWhitelistedPools\x12\x0b\n\x03ids\x18\x01 \x03(\x04*Z\n\x13SuperfluidAssetType\x12\x1d\n\x19SuperfluidAssetTypeNative\x10\x00\x12\x1e\n\x1aSuperfluidAssetTypeLPShare\x10\x01\x1a\x04\x88\xa3\x1e\x00\x42\x38Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.superfluid.superfluid_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/types'
  _SUPERFLUIDASSETTYPE._options = None
  _SUPERFLUIDASSETTYPE._serialized_options = b'\210\243\036\000'
  _SUPERFLUIDASSET._options = None
  _SUPERFLUIDASSET._serialized_options = b'\350\240\037\001\210\240\037\000'
  _OSMOEQUIVALENTMULTIPLIERRECORD.fields_by_name['multiplier']._options = None
  _OSMOEQUIVALENTMULTIPLIERRECORD.fields_by_name['multiplier']._serialized_options = b'\362\336\037\021yaml:\"multiplier\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SUPERFLUIDDELEGATIONRECORD.fields_by_name['delegation_amount']._options = None
  _SUPERFLUIDDELEGATIONRECORD.fields_by_name['delegation_amount']._serialized_options = b'\310\336\037\000\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _SUPERFLUIDDELEGATIONRECORD.fields_by_name['equivalent_staked_amount']._options = None
  _SUPERFLUIDDELEGATIONRECORD.fields_by_name['equivalent_staked_amount']._serialized_options = b'\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _SUPERFLUIDASSETTYPE._serialized_start=947
  _SUPERFLUIDASSETTYPE._serialized_end=1037
  _SUPERFLUIDASSET._serialized_start=178
  _SUPERFLUIDASSET._serialized_end=281
  _SUPERFLUIDINTERMEDIARYACCOUNT._serialized_start=283
  _SUPERFLUIDINTERMEDIARYACCOUNT._serialized_end=365
  _OSMOEQUIVALENTMULTIPLIERRECORD._serialized_start=368
  _OSMOEQUIVALENTMULTIPLIERRECORD._serialized_end=526
  _SUPERFLUIDDELEGATIONRECORD._serialized_start=529
  _SUPERFLUIDDELEGATIONRECORD._serialized_end=820
  _LOCKIDINTERMEDIARYACCOUNTCONNECTION._serialized_start=822
  _LOCKIDINTERMEDIARYACCOUNTCONNECTION._serialized_end=906
  _UNPOOLWHITELISTEDPOOLS._serialized_start=908
  _UNPOOLWHITELISTEDPOOLS._serialized_end=945
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/superfluid/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from osmosis.superfluid import superfluid_pb2 as osmosis_dot_superfluid_dot_superfluid__pb2
from osmosis.superfluid import params_pb2 as osmosis_dot_superfluid_dot_params__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eosmosis/superfluid/query.proto\x12\x12osmosis.superfluid\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#osmosis/superfluid/superfluid.proto\x1a\x1fosmosis/superfluid/params.proto\x1a\x19osmosis/lockup/lock.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a$cosmos/staking/v1beta1/staking.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.osmosis.superfluid.ParamsB\x04\xc8\xde\x1f\x00\"!\n\x10\x41ssetTypeRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"P\n\x11\x41ssetTypeResponse\x12;\n\nasset_type\x18\x01 \x01(\x0e\x32\'.osmosis.superfluid.SuperfluidAssetType\"\x12\n\x10\x41llAssetsRequest\"N\n\x11\x41llAssetsResponse\x12\x39\n\x06\x61ssets\x18\x01 \x03(\x0b\x32#.osmosis.superfluid.SuperfluidAssetB\x04\xc8\xde\x1f\x00\"\'\n\x16\x41ssetMultiplierRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"q\n\x17\x41ssetMultiplierResponse\x12V\n\x1aosmo_equivalent_multiplier\x18\x01 \x01(\x0b\x32\x32.osmosis.superfluid.OsmoEquivalentMultiplierRecord\"g\n!SuperfluidIntermediaryAccountInfo\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08val_addr\x18\x02 \x01(\t\x12\x10\n\x08gauge_id\x18\x03 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\"\\\n\x1e\x41llIntermediaryAccountsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xad\x01\n\x1f\x41llIntermediaryAccountsResponse\x12M\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x35.osmosis.superfluid.SuperfluidIntermediaryAccountInfoB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"6\n#ConnectedIntermediaryAccountRequest\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\"n\n$ConnectedIntermediaryAccountResponse\x12\x46\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x35.osmosis.superfluid.SuperfluidIntermediaryAccountInfo\"?\n.QueryTotalDelegationByValidatorForDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"h\n/QueryTotalDelegationByValidatorForDenomResponse\x12\x35\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x1f.osmosis.superfluid.DelegationsB\x04\xc8\xde\x1f\x00\"\xdd\x01\n\x0b\x44\x65legations\x12\x10\n\x08val_addr\x18\x01 \x01(\t\x12Y\n\x0b\x61mount_sfsd\x18\x02 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x12yaml:\"amount_sfsd\"\xc8\xde\x1f\x00\x12\x61\n\x0fosmo_equivalent\x18\x03 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"osmo_equivalent\"\xc8\xde\x1f\x00\"#\n!TotalSuperfluidDelegationsRequest\"\x96\x01\n\"TotalSuperfluidDelegationsResponse\x12p\n\x11total_delegations\x18\x01 \x01(\tBU\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f#yaml:\"total_superfluid_delegations\"\xc8\xde\x1f\x00\"h\n!SuperfluidDelegationAmountRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\"\x81\x01\n\"SuperfluidDelegationAmountResponse\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"D\n\'SuperfluidDelegationsByDelegatorRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t\"\xe7\x02\n(SuperfluidDelegationsByDelegatorResponse\x12[\n\x1dsuperfluid_delegation_records\x18\x01 \x03(\x0b\x32..osmosis.superfluid.SuperfluidDelegationRecordB\x04\xc8\xde\x1f\x00\x12j\n\x15total_delegated_coins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12r\n\x1etotal_equivalent_staked_amount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\"U\n)SuperfluidUndelegationsByDelegatorRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"\xb5\x02\n*SuperfluidUndelegationsByDelegatorResponse\x12[\n\x1dsuperfluid_delegation_records\x18\x01 \x03(\x0b\x32..osmosis.superfluid.SuperfluidDelegationRecordB\x04\xc8\xde\x1f\x00\x12l\n\x17total_undelegated_coins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12<\n\x0fsynthetic_locks\x18\x03 \x03(\x0b\x32\x1d.osmosis.lockup.SyntheticLockB\x04\xc8\xde\x1f\x00\"X\n,SuperfluidDelegationsByValidatorDenomRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"\x8c\x01\n-SuperfluidDelegationsByValidatorDenomResponse\x12[\n\x1dsuperfluid_delegation_records\x18\x01 \x03(\x0b\x32..osmosis.superfluid.SuperfluidDelegationRecordB\x04\xc8\xde\x1f\x00\"d\n8EstimateSuperfluidDelegatedAmountByValidatorDenomRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"\xa7\x01\n9EstimateSuperfluidDelegatedAmountByValidatorDenomResponse\x12j\n\x15total_delegated_coins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"C\n&QueryTotalDelegationByDelegatorRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t\"\xb5\x03\n\'QueryTotalDelegationByDelegatorResponse\x12[\n\x1dsuperfluid_delegation_records\x18\x01 \x03(\x0b\x32..osmosis.superfluid.SuperfluidDelegationRecordB\x04\xc8\xde\x1f\x00\x12M\n\x13\x64\x65legation_response\x18\x02 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x04\xc8\xde\x1f\x00\x12j\n\x15total_delegated_coins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12r\n\x1etotal_equivalent_staked_amount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\"\x1d\n\x1bQueryUnpoolWhitelistRequest\"0\n\x1cQueryUnpoolWhitelistResponse\x12\x10\n\x08pool_ids\x18\x01 \x03(\x04\x32\xfe\x17\n\x05Query\x12\x85\x01\n\x06Params\x12&.osmosis.superfluid.QueryParamsRequest\x1a\'.osmosis.superfluid.QueryParamsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/osmosis/superfluid/v1beta1/params\x12\x88\x01\n\tAssetType\x12$.osmosis.superfluid.AssetTypeRequest\x1a%.osmosis.superfluid.AssetTypeResponse\".\x82\xd3\xe4\x93\x02(\x12&/osmosis/superfluid/v1beta1/asset_type\x12\x88\x01\n\tAllAssets\x12$.osmosis.superfluid.AllAssetsRequest\x1a%.osmosis.superfluid.AllAssetsResponse\".\x82\xd3\xe4\x93\x02(\x12&/osmosis/superfluid/v1beta1/all_assets\x12\xa0\x01\n\x0f\x41ssetMultiplier\x12*.osmosis.superfluid.AssetMultiplierRequest\x1a+.osmosis.superfluid.AssetMultiplierResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/superfluid/v1beta1/asset_multiplier\x12\xc1\x01\n\x17\x41llIntermediaryAccounts\x12\x32.osmosis.superfluid.AllIntermediaryAccountsRequest\x1a\x33.osmosis.superfluid.AllIntermediaryAccountsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/osmosis/superfluid/v1beta1/all_intermediary_accounts\x12\xdf\x01\n\x1c\x43onnectedIntermediaryAccount\x12\x37.osmosis.superfluid.ConnectedIntermediaryAccountRequest\x1a\x38.osmosis.superfluid.ConnectedIntermediaryAccountResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/osmosis/superfluid/v1beta1/connected_intermediary_account/{lock_id}\x12\xaf\x01\n\"TotalDelegationByValidatorForDenom\x12\x42.osmosis.superfluid.QueryTotalDelegationByValidatorForDenomRequest\x1a\x43.osmosis.superfluid.QueryTotalDelegationByValidatorForDenomResponse\"\x00\x12\xcb\x01\n\x1aTotalSuperfluidDelegations\x12\x35.osmosis.superfluid.TotalSuperfluidDelegationsRequest\x1a\x36.osmosis.superfluid.TotalSuperfluidDelegationsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/osmosis/superfluid/v1beta1/all_superfluid_delegations\x12\xcd\x01\n\x1aSuperfluidDelegationAmount\x12\x35.osmosis.superfluid.SuperfluidDelegationAmountRequest\x1a\x36.osmosis.superfluid.SuperfluidDelegationAmountResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/osmosis/superfluid/v1beta1/superfluid_delegation_amount\x12\xed\x01\n SuperfluidDelegationsByDelegator\x12;.osmosis.superfluid.SuperfluidDelegationsByDelegatorRequest\x1a<.osmosis.superfluid.SuperfluidDelegationsByDelegatorResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/osmosis/superfluid/v1beta1/superfluid_delegations/{delegator_address}\x12\x82\x02\n\"SuperfluidUndelegationsByDelegator\x12=.osmosis.superfluid.SuperfluidUndelegationsByDelegatorRequest\x1a>.osmosis.superfluid.SuperfluidUndelegationsByDelegatorResponse\"]\x82\xd3\xe4\x93\x02W\x12U/osmosis/superfluid/v1beta1/superfluid_undelegations_by_delegator/{delegator_address}\x12\xfb\x01\n%SuperfluidDelegationsByValidatorDenom\x12@.osmosis.superfluid.SuperfluidDelegationsByValidatorDenomRequest\x1a\x41.osmosis.superfluid.SuperfluidDelegationsByValidatorDenomResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/osmosis/superfluid/v1beta1/superfluid_delegations_by_validator_denom\x12\xae\x02\n1EstimateSuperfluidDelegatedAmountByValidatorDenom\x12L.osmosis.superfluid.EstimateSuperfluidDelegatedAmountByValidatorDenomRequest\x1aM.osmosis.superfluid.EstimateSuperfluidDelegatedAmountByValidatorDenomResponse\"\\\x82\xd3\xe4\x93\x02V\x12T/osmosis/superfluid/v1beta1/estimate_superfluid_delegation_amount_by_validator_denom\x12\xec\x01\n\x1aTotalDelegationByDelegator\x12:.osmosis.superfluid.QueryTotalDelegationByDelegatorRequest\x1a;.osmosis.superfluid.QueryTotalDelegationByDelegatorResponse\"U\x82\xd3\xe4\x93\x02O\x12M/osmosis/superfluid/v1beta1/total_delegation_by_delegator/{delegator_address}\x12\xaa\x01\n\x0fUnpoolWhitelist\x12/.osmosis.superfluid.QueryUnpoolWhitelistRequest\x1a\x30.osmosis.superfluid.QueryUnpoolWhitelistResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/superfluid/v1beta1/unpool_whitelistB8Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.superfluid.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _ALLASSETSRESPONSE.fields_by_name['assets']._options = None
  _ALLASSETSRESPONSE.fields_by_name['assets']._serialized_options = b'\310\336\037\000'
  _ALLINTERMEDIARYACCOUNTSRESPONSE.fields_by_name['accounts']._options = None
  _ALLINTERMEDIARYACCOUNTSRESPONSE.fields_by_name['accounts']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALDELEGATIONBYVALIDATORFORDENOMRESPONSE.fields_by_name['assets']._options = None
  _QUERYTOTALDELEGATIONBYVALIDATORFORDENOMRESPONSE.fields_by_name['assets']._serialized_options = b'\310\336\037\000'
  _DELEGATIONS.fields_by_name['amount_sfsd']._options = None
  _DELEGATIONS.fields_by_name['amount_sfsd']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\022yaml:\"amount_sfsd\"\310\336\037\000'
  _DELEGATIONS.fields_by_name['osmo_equivalent']._options = None
  _DELEGATIONS.fields_by_name['osmo_equivalent']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"osmo_equivalent\"\310\336\037\000'
  _TOTALSUPERFLUIDDELEGATIONSRESPONSE.fields_by_name['total_delegations']._options = None
  _TOTALSUPERFLUIDDELEGATIONSRESPONSE.fields_by_name['total_delegations']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037#yaml:\"total_superfluid_delegations\"\310\336\037\000'
  _SUPERFLUIDDELEGATIONAMOUNTRESPONSE.fields_by_name['amount']._options = None
  _SUPERFLUIDDELEGATIONAMOUNTRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['superfluid_delegation_records']._options = None
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['superfluid_delegation_records']._serialized_options = b'\310\336\037\000'
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['total_delegated_coins']._options = None
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['total_delegated_coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['total_equivalent_staked_amount']._options = None
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['total_equivalent_staked_amount']._serialized_options = b'\310\336\037\000\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['superfluid_delegation_records']._options = None
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['superfluid_delegation_records']._serialized_options = b'\310\336\037\000'
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['total_undelegated_coins']._options = None
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['total_undelegated_coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['synthetic_locks']._options = None
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE.fields_by_name['synthetic_locks']._serialized_options = b'\310\336\037\000'
  _SUPERFLUIDDELEGATIONSBYVALIDATORDENOMRESPONSE.fields_by_name['superfluid_delegation_records']._options = None
  _SUPERFLUIDDELEGATIONSBYVALIDATORDENOMRESPONSE.fields_by_name['superfluid_delegation_records']._serialized_options = b'\310\336\037\000'
  _ESTIMATESUPERFLUIDDELEGATEDAMOUNTBYVALIDATORDENOMRESPONSE.fields_by_name['total_delegated_coins']._options = None
  _ESTIMATESUPERFLUIDDELEGATEDAMOUNTBYVALIDATORDENOMRESPONSE.fields_by_name['total_delegated_coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['superfluid_delegation_records']._options = None
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['superfluid_delegation_records']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['delegation_response']._options = None
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['delegation_response']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['total_delegated_coins']._options = None
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['total_delegated_coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['total_equivalent_staked_amount']._options = None
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE.fields_by_name['total_equivalent_staked_amount']._serialized_options = b'\310\336\037\000\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002$\022\"/osmosis/superfluid/v1beta1/params'
  _QUERY.methods_by_name['AssetType']._options = None
  _QUERY.methods_by_name['AssetType']._serialized_options = b'\202\323\344\223\002(\022&/osmosis/superfluid/v1beta1/asset_type'
  _QUERY.methods_by_name['AllAssets']._options = None
  _QUERY.methods_by_name['AllAssets']._serialized_options = b'\202\323\344\223\002(\022&/osmosis/superfluid/v1beta1/all_assets'
  _QUERY.methods_by_name['AssetMultiplier']._options = None
  _QUERY.methods_by_name['AssetMultiplier']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/superfluid/v1beta1/asset_multiplier'
  _QUERY.methods_by_name['AllIntermediaryAccounts']._options = None
  _QUERY.methods_by_name['AllIntermediaryAccounts']._serialized_options = b'\202\323\344\223\0027\0225/osmosis/superfluid/v1beta1/all_intermediary_accounts'
  _QUERY.methods_by_name['ConnectedIntermediaryAccount']._options = None
  _QUERY.methods_by_name['ConnectedIntermediaryAccount']._serialized_options = b'\202\323\344\223\002F\022D/osmosis/superfluid/v1beta1/connected_intermediary_account/{lock_id}'
  _QUERY.methods_by_name['TotalSuperfluidDelegations']._options = None
  _QUERY.methods_by_name['TotalSuperfluidDelegations']._serialized_options = b'\202\323\344\223\0028\0226/osmosis/superfluid/v1beta1/all_superfluid_delegations'
  _QUERY.methods_by_name['SuperfluidDelegationAmount']._options = None
  _QUERY.methods_by_name['SuperfluidDelegationAmount']._serialized_options = b'\202\323\344\223\002:\0228/osmosis/superfluid/v1beta1/superfluid_delegation_amount'
  _QUERY.methods_by_name['SuperfluidDelegationsByDelegator']._options = None
  _QUERY.methods_by_name['SuperfluidDelegationsByDelegator']._serialized_options = b'\202\323\344\223\002H\022F/osmosis/superfluid/v1beta1/superfluid_delegations/{delegator_address}'
  _QUERY.methods_by_name['SuperfluidUndelegationsByDelegator']._options = None
  _QUERY.methods_by_name['SuperfluidUndelegationsByDelegator']._serialized_options = b'\202\323\344\223\002W\022U/osmosis/superfluid/v1beta1/superfluid_undelegations_by_delegator/{delegator_address}'
  _QUERY.methods_by_name['SuperfluidDelegationsByValidatorDenom']._options = None
  _QUERY.methods_by_name['SuperfluidDelegationsByValidatorDenom']._serialized_options = b'\202\323\344\223\002G\022E/osmosis/superfluid/v1beta1/superfluid_delegations_by_validator_denom'
  _QUERY.methods_by_name['EstimateSuperfluidDelegatedAmountByValidatorDenom']._options = None
  _QUERY.methods_by_name['EstimateSuperfluidDelegatedAmountByValidatorDenom']._serialized_options = b'\202\323\344\223\002V\022T/osmosis/superfluid/v1beta1/estimate_superfluid_delegation_amount_by_validator_denom'
  _QUERY.methods_by_name['TotalDelegationByDelegator']._options = None
  _QUERY.methods_by_name['TotalDelegationByDelegator']._serialized_options = b'\202\323\344\223\002O\022M/osmosis/superfluid/v1beta1/total_delegation_by_delegator/{delegator_address}'
  _QUERY.methods_by_name['UnpoolWhitelist']._options = None
  _QUERY.methods_by_name['UnpoolWhitelist']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/superfluid/v1beta1/unpool_whitelist'
  _QUERYPARAMSREQUEST._serialized_start=382
  _QUERYPARAMSREQUEST._serialized_end=402
  _QUERYPARAMSRESPONSE._serialized_start=404
  _QUERYPARAMSRESPONSE._serialized_end=475
  _ASSETTYPEREQUEST._serialized_start=477
  _ASSETTYPEREQUEST._serialized_end=510
  _ASSETTYPERESPONSE._serialized_start=512
  _ASSETTYPERESPONSE._serialized_end=592
  _ALLASSETSREQUEST._serialized_start=594
  _ALLASSETSREQUEST._serialized_end=612
  _ALLASSETSRESPONSE._serialized_start=614
  _ALLASSETSRESPONSE._serialized_end=692
  _ASSETMULTIPLIERREQUEST._serialized_start=694
  _ASSETMULTIPLIERREQUEST._serialized_end=733
  _ASSETMULTIPLIERRESPONSE._serialized_start=735
  _ASSETMULTIPLIERRESPONSE._serialized_end=848
  _SUPERFLUIDINTERMEDIARYACCOUNTINFO._serialized_start=850
  _SUPERFLUIDINTERMEDIARYACCOUNTINFO._serialized_end=953
  _ALLINTERMEDIARYACCOUNTSREQUEST._serialized_start=955
  _ALLINTERMEDIARYACCOUNTSREQUEST._serialized_end=1047
  _ALLINTERMEDIARYACCOUNTSRESPONSE._serialized_start=1050
  _ALLINTERMEDIARYACCOUNTSRESPONSE._serialized_end=1223
  _CONNECTEDINTERMEDIARYACCOUNTREQUEST._serialized_start=1225
  _CONNECTEDINTERMEDIARYACCOUNTREQUEST._serialized_end=1279
  _CONNECTEDINTERMEDIARYACCOUNTRESPONSE._serialized_start=1281
  _CONNECTEDINTERMEDIARYACCOUNTRESPONSE._serialized_end=1391
  _QUERYTOTALDELEGATIONBYVALIDATORFORDENOMREQUEST._serialized_start=1393
  _QUERYTOTALDELEGATIONBYVALIDATORFORDENOMREQUEST._serialized_end=1456
  _QUERYTOTALDELEGATIONBYVALIDATORFORDENOMRESPONSE._serialized_start=1458
  _QUERYTOTALDELEGATIONBYVALIDATORFORDENOMRESPONSE._serialized_end=1562
  _DELEGATIONS._serialized_start=1565
  _DELEGATIONS._serialized_end=1786
  _TOTALSUPERFLUIDDELEGATIONSREQUEST._serialized_start=1788
  _TOTALSUPERFLUIDDELEGATIONSREQUEST._serialized_end=1823
  _TOTALSUPERFLUIDDELEGATIONSRESPONSE._serialized_start=1826
  _TOTALSUPERFLUIDDELEGATIONSRESPONSE._serialized_end=1976
  _SUPERFLUIDDELEGATIONAMOUNTREQUEST._serialized_start=1978
  _SUPERFLUIDDELEGATIONAMOUNTREQUEST._serialized_end=2082
  _SUPERFLUIDDELEGATIONAMOUNTRESPONSE._serialized_start=2085
  _SUPERFLUIDDELEGATIONAMOUNTRESPONSE._serialized_end=2214
  _SUPERFLUIDDELEGATIONSBYDELEGATORREQUEST._serialized_start=2216
  _SUPERFLUIDDELEGATIONSBYDELEGATORREQUEST._serialized_end=2284
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE._serialized_start=2287
  _SUPERFLUIDDELEGATIONSBYDELEGATORRESPONSE._serialized_end=2646
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORREQUEST._serialized_start=2648
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORREQUEST._serialized_end=2733
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE._serialized_start=2736
  _SUPERFLUIDUNDELEGATIONSBYDELEGATORRESPONSE._serialized_end=3045
  _SUPERFLUIDDELEGATIONSBYVALIDATORDENOMREQUEST._serialized_start=3047
  _SUPERFLUIDDELEGATIONSBYVALIDATORDENOMREQUEST._serialized_end=3135
  _SUPERFLUIDDELEGATIONSBYVALIDATORDENOMRESPONSE._serialized_start=3138
  _SUPERFLUIDDELEGATIONSBYVALIDATORDENOMRESPONSE._serialized_end=3278
  _ESTIMATESUPERFLUIDDELEGATEDAMOUNTBYVALIDATORDENOMREQUEST._serialized_start=3280
  _ESTIMATESUPERFLUIDDELEGATEDAMOUNTBYVALIDATORDENOMREQUEST._serialized_end=3380
  _ESTIMATESUPERFLUIDDELEGATEDAMOUNTBYVALIDATORDENOMRESPONSE._serialized_start=3383
  _ESTIMATESUPERFLUIDDELEGATEDAMOUNTBYVALIDATORDENOMRESPONSE._serialized_end=3550
  _QUERYTOTALDELEGATIONBYDELEGATORREQUEST._serialized_start=3552
  _QUERYTOTALDELEGATIONBYDELEGATORREQUEST._serialized_end=3619
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE._serialized_start=3622
  _QUERYTOTALDELEGATIONBYDELEGATORRESPONSE._serialized_end=4059
  _QUERYUNPOOLWHITELISTREQUEST._serialized_start=4061
  _QUERYUNPOOLWHITELISTREQUEST._serialized_end=4090
  _QUERYUNPOOLWHITELISTRESPONSE._serialized_start=4092
  _QUERYUNPOOLWHITELISTRESPONSE._serialized_end=4140
  _QUERY._serialized_start=4143
  _QUERY._serialized_end=7213
# @@protoc_insertion_point(module_scope)
